import { useEffect, useState, useRef } from 'react';
export const useHighlightedTextHook = () => {
    const [showPopover, setShowPopover] = useState(false);
    const [axis, setAxis] = useState({
        x: 0,
        y: 0,
    });
    const [textRange, setTextRange] = useState({
        from: 0,
        to: 0,
    });
    const [selectedText, setSelectedText] = useState('');
    const highlight = useRef();
    useEffect(() => {
        // window.addEventListener('mouseup', onMouseUp);
        // return () => window.removeEventListener('mouseup', onMouseUp);
    }, []);
    const hidePopover = () => {
        setShowPopover(false);
    };
    const onMouseUp = () => {
        const selection = window.getSelection();
        if ((selection === null || selection === void 0 ? void 0 : selection.rangeCount) === 0) {
            hidePopover();
            clearSelection();
        }
        const range = selection === null || selection === void 0 ? void 0 : selection.getRangeAt(0);
        const text = range === null || range === void 0 ? void 0 : range.toString();
        if (!text) {
            hidePopover();
            clearSelection();
        }
        else {
            const startNode = range === null || range === void 0 ? void 0 : range.startContainer;
            const endNode = range === null || range === void 0 ? void 0 : range.endContainer;
            const startIndex = ((range === null || range === void 0 ? void 0 : range.startOffset) || 0) + getNodeIndex(startNode);
            const endIndex = ((range === null || range === void 0 ? void 0 : range.endOffset) || 0) + getNodeIndex(endNode);
            const start = Math.min(startIndex, endIndex);
            const end = Math.max(startIndex, endIndex) - 1;
            const textRect = range === null || range === void 0 ? void 0 : range.getBoundingClientRect();
            const popoverTop = (textRect === null || textRect === void 0 ? void 0 : textRect.top) || 0;
            const popoverLeft = ((textRect === null || textRect === void 0 ? void 0 : textRect.x) || 0) + ((textRect === null || textRect === void 0 ? void 0 : textRect.width) || 0) / 2;
            setShowPopover(true);
            setAxis({ y: popoverTop - 94 - window.scrollY, x: popoverLeft });
            setSelectedText(text);
            setTextRange({
                from: start,
                to: end,
            });
        }
    };
    function getNodeIndex(node) {
        let index = 0;
        while ((node = node.previousSibling)) {
            index += (node.textContent || '').length;
        }
        return index;
    }
    const clearSelection = () => {
        const selection = window.getSelection();
        if (((selection === null || selection === void 0 ? void 0 : selection.rangeCount) || 0) > 0) {
            selection === null || selection === void 0 ? void 0 : selection.removeAllRanges();
        }
    };
    return {
        highlight,
        showPopover,
        selectedText,
        axis,
        textRange,
        clearSelection,
        onMouseUp,
    };
};
//# sourceMappingURL=useHighlightedTextHook.js.map